==> kubernetes-model-batch-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public class UncountedTerminatedPodsFluentImpl<A extends io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<A>{
  public UncountedTerminatedPodsFluentImpl() {
  }
  public UncountedTerminatedPodsFluentImpl(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance) {
    this.withFailed(instance.getFailed()); 
    this.withSucceeded(instance.getSucceeded()); 
  }
  private java.util.List<java.lang.String> failed = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> succeeded = new java.util.ArrayList<java.lang.String>();
  public A addToFailed(java.lang.Integer index,java.lang.String item) {
    if (this.failed == null) {this.failed = new java.util.ArrayList<java.lang.String>();}
    this.failed.add(index, item);
    return (A)this;
  }
  public A setToFailed(java.lang.Integer index,java.lang.String item) {
    if (this.failed == null) {this.failed = new java.util.ArrayList<java.lang.String>();}
    this.failed.set(index, item); return (A)this;
  }
  public A addToFailed(java.lang.String... items) {
    if (this.failed == null) {this.failed = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.failed.add(item);} return (A)this;
  }
  public A addAllToFailed(java.util.Collection<java.lang.String> items) {
    if (this.failed == null) {this.failed = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.failed.add(item);} return (A)this;
  }
  public A removeFromFailed(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.failed!= null){ this.failed.remove(item);}} return (A)this;
  }
  public A removeAllFromFailed(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.failed!= null){ this.failed.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getFailed() {
    return this.failed;
  }
  public java.lang.String getFailed(java.lang.Integer index) {
    return this.failed.get(index);
  }
  public java.lang.String getFirstFailed() {
    return this.failed.get(0);
  }
  public java.lang.String getLastFailed() {
    return this.failed.get(failed.size() - 1);
  }
  public java.lang.String getMatchingFailed(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: failed) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingFailed(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: failed) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withFailed(java.util.List<java.lang.String> failed) {
    if (failed != null) {this.failed = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : failed){this.addToFailed(item);}} else { this.failed = null;} return (A) this;
  }
  public A withFailed(java.lang.String... failed) {
    if (this.failed != null) {this.failed.clear();}
    if (failed != null) {for (java.lang.String item :failed){ this.addToFailed(item);}} return (A) this;
  }
  public java.lang.Boolean hasFailed() {
    return failed != null && !failed.isEmpty();
  }
  public A addNewFailed(java.lang.String arg0) {
    return (A)addToFailed(new String(arg0));
  }
  public A addToSucceeded(java.lang.Integer index,java.lang.String item) {
    if (this.succeeded == null) {this.succeeded = new java.util.ArrayList<java.lang.String>();}
    this.succeeded.add(index, item);
    return (A)this;
  }
  public A setToSucceeded(java.lang.Integer index,java.lang.String item) {
    if (this.succeeded == null) {this.succeeded = new java.util.ArrayList<java.lang.String>();}
    this.succeeded.set(index, item); return (A)this;
  }
  public A addToSucceeded(java.lang.String... items) {
    if (this.succeeded == null) {this.succeeded = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.succeeded.add(item);} return (A)this;
  }
  public A addAllToSucceeded(java.util.Collection<java.lang.String> items) {
    if (this.succeeded == null) {this.succeeded = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.succeeded.add(item);} return (A)this;
  }
  public A removeFromSucceeded(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.succeeded!= null){ this.succeeded.remove(item);}} return (A)this;
  }
  public A removeAllFromSucceeded(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.succeeded!= null){ this.succeeded.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSucceeded() {
    return this.succeeded;
  }
  public java.lang.String getSucceeded(java.lang.Integer index) {
    return this.succeeded.get(index);
  }
  public java.lang.String getFirstSucceeded() {
    return this.succeeded.get(0);
  }
  public java.lang.String getLastSucceeded() {
    return this.succeeded.get(succeeded.size() - 1);
  }
  public java.lang.String getMatchingSucceeded(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: succeeded) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSucceeded(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: succeeded) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSucceeded(java.util.List<java.lang.String> succeeded) {
    if (succeeded != null) {this.succeeded = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : succeeded){this.addToSucceeded(item);}} else { this.succeeded = null;} return (A) this;
  }
  public A withSucceeded(java.lang.String... succeeded) {
    if (this.succeeded != null) {this.succeeded.clear();}
    if (succeeded != null) {for (java.lang.String item :succeeded){ this.addToSucceeded(item);}} return (A) this;
  }
  public java.lang.Boolean hasSucceeded() {
    return succeeded != null && !succeeded.isEmpty();
  }
  public A addNewSucceeded(java.lang.String arg0) {
    return (A)addToSucceeded(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UncountedTerminatedPodsFluentImpl that = (UncountedTerminatedPodsFluentImpl) o;
    if (failed != null ? !failed.equals(that.failed) :that.failed != null) return false;
    if (succeeded != null ? !succeeded.equals(that.succeeded) :that.succeeded != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(failed,  succeeded,  super.hashCode());
  }
  
}

==> kubernetes-model-batch-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class UncountedTerminatedPodsFluentImpl<A extends io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<A>{
  public UncountedTerminatedPodsFluentImpl() {
  }
  public UncountedTerminatedPodsFluentImpl(io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPods instance) {
    this.withFailed(instance.getFailed()); 
    this.withSucceeded(instance.getSucceeded()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> failed = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> succeeded = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToFailed(java.lang.Integer index,java.lang.String item) {
    if (this.failed == null) {this.failed = new java.util.ArrayList<java.lang.String>();}
    this.failed.add(index, item);
    return (A)this;
  }
  public A setToFailed(java.lang.Integer index,java.lang.String item) {
    if (this.failed == null) {this.failed = new java.util.ArrayList<java.lang.String>();}
    this.failed.set(index, item); return (A)this;
  }
  public A addToFailed(java.lang.String... items) {
    if (this.failed == null) {this.failed = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.failed.add(item);} return (A)this;
  }
  public A addAllToFailed(java.util.Collection<java.lang.String> items) {
    if (this.failed == null) {this.failed = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.failed.add(item);} return (A)this;
  }
  public A removeFromFailed(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.failed!= null){ this.failed.remove(item);}} return (A)this;
  }
  public A removeAllFromFailed(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.failed!= null){ this.failed.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getFailed() {
    return this.failed;
  }
  public java.lang.String getFailed(java.lang.Integer index) {
    return this.failed.get(index);
  }
  public java.lang.String getFirstFailed() {
    return this.failed.get(0);
  }
  public java.lang.String getLastFailed() {
    return this.failed.get(failed.size() - 1);
  }
  public java.lang.String getMatchingFailed(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: failed) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingFailed(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: failed) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withFailed(java.util.List<java.lang.String> failed) {
    if (failed != null) {this.failed = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : failed){this.addToFailed(item);}} else { this.failed = null;} return (A) this;
  }
  public A withFailed(java.lang.String... failed) {
    if (this.failed != null) {this.failed.clear();}
    if (failed != null) {for (java.lang.String item :failed){ this.addToFailed(item);}} return (A) this;
  }
  public java.lang.Boolean hasFailed() {
    return failed != null && !failed.isEmpty();
  }
  public A addNewFailed(java.lang.String arg0) {
    return (A)addToFailed(new String(arg0));
  }
  public A addToSucceeded(java.lang.Integer index,java.lang.String item) {
    if (this.succeeded == null) {this.succeeded = new java.util.ArrayList<java.lang.String>();}
    this.succeeded.add(index, item);
    return (A)this;
  }
  public A setToSucceeded(java.lang.Integer index,java.lang.String item) {
    if (this.succeeded == null) {this.succeeded = new java.util.ArrayList<java.lang.String>();}
    this.succeeded.set(index, item); return (A)this;
  }
  public A addToSucceeded(java.lang.String... items) {
    if (this.succeeded == null) {this.succeeded = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.succeeded.add(item);} return (A)this;
  }
  public A addAllToSucceeded(java.util.Collection<java.lang.String> items) {
    if (this.succeeded == null) {this.succeeded = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.succeeded.add(item);} return (A)this;
  }
  public A removeFromSucceeded(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.succeeded!= null){ this.succeeded.remove(item);}} return (A)this;
  }
  public A removeAllFromSucceeded(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.succeeded!= null){ this.succeeded.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getSucceeded() {
    return this.succeeded;
  }
  public java.lang.String getSucceeded(java.lang.Integer index) {
    return this.succeeded.get(index);
  }
  public java.lang.String getFirstSucceeded() {
    return this.succeeded.get(0);
  }
  public java.lang.String getLastSucceeded() {
    return this.succeeded.get(succeeded.size() - 1);
  }
  public java.lang.String getMatchingSucceeded(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: succeeded) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingSucceeded(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: succeeded) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSucceeded(java.util.List<java.lang.String> succeeded) {
    if (succeeded != null) {this.succeeded = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : succeeded){this.addToSucceeded(item);}} else { this.succeeded = null;} return (A) this;
  }
  public A withSucceeded(java.lang.String... succeeded) {
    if (this.succeeded != null) {this.succeeded.clear();}
    if (succeeded != null) {for (java.lang.String item :succeeded){ this.addToSucceeded(item);}} return (A) this;
  }
  public java.lang.Boolean hasSucceeded() {
    return succeeded != null && !succeeded.isEmpty();
  }
  public A addNewSucceeded(java.lang.String arg0) {
    return (A)addToSucceeded(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UncountedTerminatedPodsFluentImpl that = (UncountedTerminatedPodsFluentImpl) o;
    if (failed != null ? !failed.equals(that.failed) :that.failed != null) return false;
    if (succeeded != null ? !succeeded.equals(that.succeeded) :that.succeeded != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(failed,  succeeded,  additionalProperties,  super.hashCode());
  }
  
}
